==> qgis-deployment-toolbelt-0.5.0.tar.gz: qgis-deployment-toolbelt-0.5.0/README.md <==
# QGIS Deployment CLI

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![flake8](https://img.shields.io/badge/linter-flake8-green)](https://flake8.pycqa.org/)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/Guts/qgis-deployment-cli/main.svg)](https://results.pre-commit.ci/latest/github/Guts/qgis-deployment-cli/main)

[![🎳 Tester](https://github.com/Guts/qgis-deployment-cli/actions/workflows/tests.yml/badge.svg)](https://github.com/Guts/qgis-deployment-cli/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/Guts/qgis-deployment-cli/branch/main/graph/badge.svg?token=ZHGRNMA7TV)](https://codecov.io/gh/Guts/qgis-deployment-cli)
[![📦 Build & 🚀 Release](https://github.com/Guts/qgis-deployment-cli/actions/workflows/build_release.yml/badge.svg?branch=main)](https://github.com/Guts/qgis-deployment-cli/actions/workflows/build_release.yml)

Cross-platform (but Windows focused) CLI to perform deployment operations: profiles, plugins, etc.

**Interested**? For further details, [read the documentation](https://guts.github.io/qgis-deployment-cli//) :books:.

## Contribute

Read the [contribution guidelines](CONTRIBUTING.md) and the documentation.

==> qgis-deployment-toolbelt-0.14.0.tar.gz: qgis-deployment-toolbelt-0.14.0/README.md <==
# QGIS Deployment CLI

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![flake8](https://img.shields.io/badge/linter-flake8-green)](https://flake8.pycqa.org/)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/Guts/qgis-deployment-cli/main.svg)](https://results.pre-commit.ci/latest/github/Guts/qgis-deployment-cli/main)

[![🎳 Tester](https://github.com/Guts/qgis-deployment-cli/actions/workflows/tests.yml/badge.svg)](https://github.com/Guts/qgis-deployment-cli/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/Guts/qgis-deployment-cli/branch/main/graph/badge.svg?token=ZHGRNMA7TV)](https://codecov.io/gh/Guts/qgis-deployment-cli)
[![📦 Build & 🚀 Release](https://github.com/Guts/qgis-deployment-cli/actions/workflows/build_release.yml/badge.svg?branch=main)](https://github.com/Guts/qgis-deployment-cli/actions/workflows/build_release.yml)

[![PyPi version badge](https://badgen.net/pypi/v/qgis-deployment-toolbelt)](https://pypi.org/project/qgis-deployment-toolbelt/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/qgis-deployment-toolbelt)](https://pypi.org/project/qgis-deployment-toolbelt/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/qgis-deployment-toolbelt)](https://pypi.org/project/qgis-deployment-toolbelt/)

Cross-platform (but Windows focused) CLI to perform deployment operations: profiles, plugins, etc.

**Interested**? For further details, [read the documentation](https://guts.github.io/qgis-deployment-cli//) :books:.

## Contribute

Read the [contribution guidelines](CONTRIBUTING.md) and the documentation.
